==> component-redis-1.0.0-20180823.120550-14-sources.jar: com/bxm/newidea/component/redis/impl/BaseRedisAdapter.java <==
package com.bxm.newidea.component.redis.impl;

import com.bxm.newidea.component.redis.BaseRedisOperation;
import com.bxm.newidea.component.redis.KeyGenerator;
import org.apache.commons.lang3.ArrayUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.data.redis.serializer.JdkSerializationRedisSerializer;
import org.springframework.data.redis.serializer.RedisSerializer;
import org.springframework.data.redis.serializer.StringRedisSerializer;
import org.springframework.util.CollectionUtils;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.concurrent.TimeUnit;
import java.util.stream.Collectors;

/**
 * 基础redis操作代理
 * @author liujia 2018/5/21 17:35
 */
public class BaseRedisAdapter implements BaseRedisOperation {

    protected Logger logger = LoggerFactory.getLogger(this.getClass());

    protected RedisTemplate<String, Object> redisTemplate;

    protected JdkSerializationRedisSerializer serializer;

    protected RedisSerializer<String> stringSerializer;

    public BaseRedisAdapter(RedisTemplate<String, Object> redisTemplate) {
        this.redisTemplate = redisTemplate;
        this.serializer = new JdkSerializationRedisSerializer(this.getClass().getClassLoader());
        this.stringSerializer = new StringRedisSerializer();
    }

    @Override
    public boolean remove(KeyGenerator key) {
        return this.redisTemplate.delete(key.gen());
    }

    @Override
    public long remove(List<KeyGenerator> keys) {
        if (CollectionUtils.isEmpty(keys)) {
            return 0L;
        }

        List<String> finalKeys = keys.stream().map(KeyGenerator::gen).collect(Collectors.toList());
        return this.redisTemplate.delete(finalKeys);
    }

    @Override
    public void expire(KeyGenerator key, long seconds) {
        if (seconds > 0) {
            this.redisTemplate.expire(key.gen(), seconds, TimeUnit.SECONDS);
        }
    }

    @Override
    public void expire(KeyGenerator key, Date expiredDate) {
        if (null != expiredDate) {
            this.redisTemplate.expireAt(key.gen(), expiredDate);
        }
    }

    @Override
    public boolean hasKey(KeyGenerator key) {
        return this.redisTemplate.hasKey(key.gen());
    }

    protected <T> T deserialize(Object value) {
        if (value instanceof byte[]) {
            return (T) this.serializer.deserialize((byte[]) value);
        }
        this.logger.warn("redis返回数据不能进行反序列化，请检查是否配置了自定义的序列");
        return null;
    }

    protected byte[][] serialize(String[] values) {
        byte[][] result = new byte[values.length][];

        for (int i = 0; i < values.length; i++) {
            result[i] = this.stringSerializer.serialize(values[i]);
        }

        return result;
    }

    protected byte[][] serialize(Object[] values) {
        byte[][] result = new byte[values.length][];

        for (int i = 0; i < values.length; i++) {
            result[i] = this.serializer.serialize(values[i]);
        }

        return result;
    }

    protected List<String> convertKeys(KeyGenerator... generators) {
        if (ArrayUtils.isEmpty(generators)) {
            return null;
        }

        List<String> keys = new ArrayList<>();

        for (KeyGenerator generator : generators) {
            keys.add(generator.gen());
        }

        return keys;
    }
}

==> component-redis-1.1.0-20181009.114604-2-sources.jar: com/bxm/newidea/component/redis/impl/BaseRedisAdapter.java <==
package com.bxm.newidea.component.redis.impl;

import com.bxm.newidea.component.redis.BaseRedisOperation;
import com.bxm.newidea.component.redis.KeyGenerator;
import org.apache.commons.lang3.ArrayUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.data.redis.serializer.Jackson2JsonRedisSerializer;
import org.springframework.data.redis.serializer.RedisSerializer;
import org.springframework.data.redis.serializer.StringRedisSerializer;
import org.springframework.util.CollectionUtils;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.concurrent.TimeUnit;
import java.util.stream.Collectors;

/**
 * 基础redis操作代理
 * @author liujia 2018/5/21 17:35
 */
public class BaseRedisAdapter implements BaseRedisOperation {

    RedisTemplate<String, Object> redisTemplate;
    RedisSerializer<String> stringSerializer;
    private Logger logger = LoggerFactory.getLogger(this.getClass());

    public BaseRedisAdapter(RedisTemplate<String, Object> redisTemplate) {
        this.redisTemplate = redisTemplate;
        this.stringSerializer = new StringRedisSerializer();
    }

    @Override
    public Boolean remove(KeyGenerator key) {
        return this.redisTemplate.delete(key.gen());
    }

    @Override
    public Long remove(List<KeyGenerator> keys) {
        if (CollectionUtils.isEmpty(keys)) {
            return 0L;
        }

        List<String> finalKeys = keys.stream().map(KeyGenerator::gen).collect(Collectors.toList());
        return this.redisTemplate.delete(finalKeys);
    }

    @Override
    public void expire(KeyGenerator key, long seconds) {
        if (seconds > 0) {
            this.redisTemplate.expire(key.gen(), seconds, TimeUnit.SECONDS);
        }
    }

    @Override
    public void expire(KeyGenerator key, Date expiredDate) {
        if (null != expiredDate) {
            this.redisTemplate.expireAt(key.gen(), expiredDate);
        }
    }

    @Override
    public Boolean hasKey(KeyGenerator key) {
        return this.redisTemplate.hasKey(key.gen());
    }

    <T> RedisSerializer getSerializer(Class<T> clasz) {
        return new Jackson2JsonRedisSerializer(clasz);
    }

    RedisSerializer getSerializerWithoutType() {
        return new Jackson2JsonRedisSerializer(Object.class);
    }

    <T> T deserialize(Object value, Class<T> clasz) {
        if (value instanceof byte[]) {
            return (T) this.getSerializer(clasz).deserialize((byte[]) value);
        }
        this.logger.warn("redis返回数据不能进行反序列化，请检查是否配置了自定义的序列");
        return null;
    }

    protected byte[][] serialize(String[] values) {
        byte[][] result = new byte[values.length][];

        for (int i = 0; i < values.length; i++) {
            result[i] = this.stringSerializer.serialize(values[i]);
        }

        return result;
    }

    <T> byte[][] serialize(Object[] values, Class<T> clasz) {
        byte[][] result = new byte[values.length][];

        for (int i = 0; i < values.length; i++) {
            result[i] = this.getSerializer(clasz).serialize(values[i]);
        }

        return result;
    }

    <T> byte[][] serializeWithoutType(T[] values) {
        return serialize(values, Object.class);
    }

    List<String> convertKeys(KeyGenerator... generators) {
        if (ArrayUtils.isEmpty(generators)) {
            return null;
        }

        List<String> keys = new ArrayList<>();

        for (KeyGenerator generator : generators) {
            keys.add(generator.gen());
        }

        return keys;
    }
}
